@@ -522,7 +522,7 @@ test -x $runitconf_prog && runitconf_entry=$(entry \
     $"Select what system services should be started automatically when booting antiX (runit).")
 
 ufwtoggle_prog=/usr/local/bin/antix_firewall_toggle
-test -x $ufwtoggleconf_prog && ufwtoggle_entry=$(entry \
+test -x $ufwtoggle_prog && ufwtoggle_entry=$(entry \
     $ICONS/gufw.png \
     "/usr/local/bin/antix_firewall_toggle &" \
     $"Toggle Firewall on/off" \
